run_fuse_mount

Function run_fuse_mount 

pub(crate) fn run_fuse_mount<ObjectID: FsVerityHashValue>(
    repo: &Arc<Repository<ObjectID>>,
    name: &str,
    mountpoint: &str,
    mode: MountMode,
    mount_options: MountOptions,
    foreground: bool,
) -> Result<()>
Re-exec ourselves as --internal-fuse-serve to run the FUSE server in a clean process without the tokio runtime. File descriptors are passed via the systemd socket activation protocol (LISTEN_FDS/LISTEN_FDNAMES) for safe and easy fd transfer.